package ru.sinitsynme.sellingmarket;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.CommandLineRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Conditional;
import ru.sinitsynme.sellingmarket.entity.*;
import ru.sinitsynme.sellingmarket.entity.dto.UserDto;
import ru.sinitsynme.sellingmarket.repository.*;
import ru.sinitsynme.sellingmarket.service.UserService;

import java.util.List;

@SpringBootApplication
public class SellingServiceApplication {

	private final UserService userService;

	private final UserRoleRepository userRoleRepository;
	private final AdvTypeRepository advTypeRepository;
	private final AdvSubcategoryRepository subcategoryRepository;
	private final AdvCategoryRepository categoryRepository;

	private final UserDto userDto = new UserDto("admin", new char[]{'1', '2', '3'});

	private final AdvCategory advCategory = new AdvCategory("авто");

	public SellingServiceApplication(UserService userService, UserRoleRepository userRoleRepository,
									 AdvTypeRepository advTypeRepository, AdvSubcategoryRepository subcategoryRepository,
									 AdvCategoryRepository categoryRepository) {
		this.userService = userService;
		this.userRoleRepository = userRoleRepository;
		this.advTypeRepository = advTypeRepository;
		this.subcategoryRepository = subcategoryRepository;
		this.categoryRepository = categoryRepository;
	}

	public static void main(String[] args) {
		SpringApplication.run(SellingServiceApplication.class, args);
	}

	//Adding necessary data

	@Bean
	@ConditionalOnProperty(name = "spring.jpa.hibernate.ddl-auto", havingValue = "create")
	public CommandLineRunner commandLineRunner(){

		return (args) -> {

			userRoleRepository.saveAll(List.of(new UserRole("ROLE_ADMIN"),
					new UserRole("ROLE_MODERATOR"), new UserRole("ROLE_USER")));

			advTypeRepository.saveAll(List.of(new AdvType("куплю"), new AdvType("продам"), new AdvType("обменяю")));
			categoryRepository.saveAll(List.of(new AdvCategory("авто"), new AdvCategory("недвижимость"), new AdvCategory("техника")));
			subcategoryRepository.saveAll(List.of(new AdvSubcategory("новое"), new AdvSubcategory("б/у"), new AdvSubcategory("двухкомнатная")));

			List<AdvSubcategory> subcategoryList = subcategoryRepository.findAll();

			User user = userService.addUser(userDto);

			userService.editRole("ROLE_ADMIN", user.getId());
		};
	}

}
