package ru.sinitsynme.sellingmarket.entity;


import com.fasterxml.jackson.annotation.JsonIgnore;

import javax.persistence.*;
import javax.validation.constraints.NotBlank;
import java.util.Date;
import java.util.List;
import java.util.UUID;

@Entity
public class Advertisement {

    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private UUID id;

    private String name;

    private String text;

    @Temporal(TemporalType.DATE)
    private Date date;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "user_id")
    @JsonIgnore
    private User user;

    @ManyToOne(fetch = FetchType.EAGER)
    @JoinColumn(name = "type_id")
    private AdvType advType;

    @ManyToOne( fetch = FetchType.EAGER)
    @JoinColumn(name="category_id")
    private AdvCategory advCategory;

    @ManyToMany(fetch = FetchType.LAZY)
    @JoinTable(name = "mtm_adv_subcategory", joinColumns = @JoinColumn(name = "subcategory_id"), inverseJoinColumns = @JoinColumn(name = "adv_id"))
    private List<AdvSubcategory> advSubcategoryList;

    @OneToMany(mappedBy = "advertisement", orphanRemoval = true, cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    private List<Link> links;

    public Advertisement() {
    }

    public Advertisement(String name, String text, Date date) {
        this.name = name;
        this.text = text;
        this.date = date;
    }

    public UUID getId() {
        return id;
    }

    public void setId(UUID id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getText() {
        return text;
    }

    public void setText(String text) {
        this.text = text;
    }

    public void setDate(Date date) {
        this.date = date;
    }

    public Date getDate() {
        return date;
    }

    public User getUser() {
        return user;
    }

    public void setUser(User user) {
        this.user = user;
    }

    public AdvType getAdvType() {
        return advType;
    }

    public void setAdvType(AdvType advType) {
        this.advType = advType;
    }

    public AdvCategory getAdvCategory() {
        return advCategory;
    }

    public void setAdvCategory(AdvCategory advCategory) {
        this.advCategory = advCategory;
    }

    public List<Link> getLinks() {
        return links;
    }

    public void setLinks(List<Link> links) {
        this.links = links;
    }

    public List<AdvSubcategory> getAdvSubcategoryList() {
        return advSubcategoryList;
    }

    public void setAdvSubcategoryList(List<AdvSubcategory> advSubcategoryList) {
        this.advSubcategoryList = advSubcategoryList;
    }
}
