package ru.sinitsynme.sellingmarket.rest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.annotation.Secured;
import org.springframework.web.bind.annotation.*;
import ru.sinitsynme.sellingmarket.entity.User;
import ru.sinitsynme.sellingmarket.entity.dto.UserDto;
import ru.sinitsynme.sellingmarket.exception.ForbiddenException;
import ru.sinitsynme.sellingmarket.service.UserService;

import javax.validation.Valid;
import java.nio.CharBuffer;
import java.util.UUID;

@RestController
@RequestMapping("/users")
public class UserController {

    private final UserService userService;

    @Autowired
    public UserController(UserService userService) {
        this.userService = userService;
    }

    @GetMapping("/{id}")

    public ResponseEntity<User> getUser(@PathVariable UUID id){
        return ResponseEntity.ok(userService.getUser(id));
    }

    @PostMapping("/register")
    public ResponseEntity<User> register(@RequestBody UserDto userDto){

        //checking username != password (password is char[] to prevent hacking it from pool)

        if(CharBuffer.wrap(userDto.getUsername()).equals(CharBuffer.wrap(userDto.getPassword()))){
            throw new ForbiddenException("Username and password should not match!");
        }

        return ResponseEntity.ok(userService.addUser(userDto));
    }

    @PatchMapping("/role/{id}")
    @Secured({"ROLE_ADMIN"})
    public ResponseEntity<User> editRole(String role, @PathVariable UUID userId){
        return ResponseEntity.ok(userService.editRole(role, userId));
    }

    @PatchMapping("/edit/{id}")
    @Secured({"ROLE_ADMIN", "ROLE_MODERATOR", "ROLE_USER"})
    public ResponseEntity<User> editUsername(String username, @PathVariable UUID userId){
        return ResponseEntity.ok(userService.editName(username, userId));
    }

    @DeleteMapping("/delete/{id}")
    @Secured({"ROLE_ADMIN", "ROLE_MODERATOR", "ROLE_USER"})
    public ResponseEntity<?> deleteUser(@PathVariable UUID userId){

        userService.deleteUser(userId);
        return ResponseEntity.ok().build();
    }

    @PostMapping("/enable/{id}")
    @Secured({"ROLE_ADMIN", "ROLE_MODERATOR"})
    public ResponseEntity<?> switchEnable(@PathVariable UUID userId, @RequestParam boolean enabled){

        userService.changeAdvertisementRights(userId, enabled);
        return ResponseEntity.ok().build();
    }

}
