package ru.sinitsynme.sellingmarket.service.impl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import ru.sinitsynme.sellingmarket.entity.AdvCategory;
import ru.sinitsynme.sellingmarket.exception.ResourceNotFoundException;
import ru.sinitsynme.sellingmarket.repository.AdvCategoryRepository;
import ru.sinitsynme.sellingmarket.service.AdvCategoryService;

import java.util.List;

@Service
public class AdvCategoryServiceImpl implements AdvCategoryService {

    private final AdvCategoryRepository categoryRepository;

    @Autowired
    public AdvCategoryServiceImpl(AdvCategoryRepository categoryRepository) {
        this.categoryRepository = categoryRepository;
    }

    @Override
    public List<AdvCategory> getAll() {
        return categoryRepository.findAll();
    }

    @Override
    public AdvCategory addCategory(AdvCategory category) {
        return categoryRepository.save(category);
    }

    public AdvCategory getByName(String name) {
        return categoryRepository.findByCategoryName(name);
    }

    @Override
    public void deleteCategory(Integer id) {
        if(!existsById(id)) throw new ResourceNotFoundException(String.format("Category with id = %d not found", id ));
        categoryRepository.deleteById(id);
    }

    @Override
    public boolean existsById(Integer id) {
        return categoryRepository.existsById(id);
    }
}
