package ru.sinitsynme.sellingmarket.service.impl;

import org.springframework.stereotype.Service;
import ru.sinitsynme.sellingmarket.entity.AdvSubcategory;
import ru.sinitsynme.sellingmarket.exception.ResourceNotFoundException;
import ru.sinitsynme.sellingmarket.repository.AdvSubcategoryRepository;
import ru.sinitsynme.sellingmarket.service.AdvSubcategoryService;

import java.util.List;
import java.util.stream.Collectors;

@Service
public class AdvSubcategoryServiceImpl implements AdvSubcategoryService {

    private final AdvSubcategoryRepository subcategoryRepository;

    public AdvSubcategoryServiceImpl(AdvSubcategoryRepository subcategoryRepository) {
        this.subcategoryRepository = subcategoryRepository;
    }

    @Override
    public List<AdvSubcategory> getAll() {
        return subcategoryRepository.findAll();
    }

    @Override
    public List<AdvSubcategory> getAllByNames(List<String> names) {
        return getAll().stream().filter(it -> names.contains(it.getSubcategoryName().toLowerCase().trim()))
                .collect(Collectors.toList());
    }

    @Override
    public AdvSubcategory addSubcategory(AdvSubcategory subcategory) {
        return subcategoryRepository.save(subcategory);
    }

    @Override
    public void deleteCategory(Integer id) {
        if(!existsById(id)) throw new ResourceNotFoundException(String.format("Subcategory with id = %d not found", id ));
        subcategoryRepository.deleteById(id);
    }

    @Override
    public boolean existsById(Integer id) {
        return subcategoryRepository.existsById(id);
    }

    @Override
    public AdvSubcategory getSubCategoryByName(String name) {
        return subcategoryRepository.findBySubcategoryName(name).orElseThrow(
                () -> new ResourceNotFoundException(String.format("Subcategory with name = %s not found", name)
        ));
    }
}
