package ru.sinitsynme.sellingmarket.service.impl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PostAuthorize;
import org.springframework.stereotype.Service;
import ru.sinitsynme.sellingmarket.entity.AdvType;
import ru.sinitsynme.sellingmarket.exception.ResourceNotFoundException;
import ru.sinitsynme.sellingmarket.repository.AdvTypeRepository;
import ru.sinitsynme.sellingmarket.service.AdvTypeService;

import java.util.List;
import java.util.UUID;

@Service
public class AdvTypeServiceImpl implements AdvTypeService {

    private final AdvTypeRepository advTypeRepository;


    @Autowired
    public AdvTypeServiceImpl(AdvTypeRepository advTypeRepository) {
        this.advTypeRepository = advTypeRepository;
    }


    @Override
    public List<AdvType> getAll() {
        return advTypeRepository.findAll();
    }

    @Override
    public AdvType addType(AdvType type) {
        return advTypeRepository.save(type);
    }

    @Override
    public AdvType getByName(String name) {
        return advTypeRepository.findByName(name).orElseThrow(
                () -> new ResourceNotFoundException(String.format("Type with name = %s not found", name ))
        );
    }

    @Override
    public void deleteType(Integer id) {
        if(!existsById(id)) throw new ResourceNotFoundException(String.format("Type with id = %d not found", id ));
        advTypeRepository.deleteById(id);

    }

    @Override
    public boolean existsById(Integer id) {
        return advTypeRepository.existsById(id);
    }
}
